
# This is the analysis script we used to produce all figures and results reported in the manuscript.
# / Anders Sand, 2021-04-01.

rm(list = ls()) # Clear workspace

# Function to calculate Clopper-Pearson Confidence interval around a proportion
CIp <- function(k, n, conf = .95) {
  # This function calculates Clopper-Pearson "exact" confidence intervals ...
  # ... based on the binomial distribution. These are sometimes criticized ...
  # ... for being too conservative / wide.
  # k = successes / outcome of interest
  # n = number of trials / individuals / chances
  # conf = confidence level the interval, defaults to .95
  # / Anders Sand
  ll <- qbeta((1 - conf)/2, k, n - k + 1)
  ul <- qbeta(1 - (1 - conf)/2, k + 1, n - k)
  out <- list(conf.level = conf, prop = k/n, conf.int = c(ll, ul))
  return(out)
}




################### Read in and preprocess data ###################
library('readxl') # Library to read Excel files
d1 <- read_excel("C:/Users/andesa1/OneDrive - KI.SE/Dokument/LKG/Part2_systematicReview/Arbete/Fulltext/klin_rel_tabulering.xlsx", sheet = "Speech") # Read Excelfile

# Recode variables to factors
d1$Study <- factor(d1$Study)
d1$RelevantC <- factor(d1$RelevantC)
d1$EndPoint <- factor(d1$EndPoint)

# Exclude some (see Excelfile)
d2 <- d1[d1$RelevantC!="Excl", c(1, 4, 5, 9, 11, 15, 16)]
d2$RelevantC <- droplevels(d2$RelevantC)
d2$EndPoint <- droplevels(d2$EndPoint)
d2$Months <- round(d2$Months)

# Look at data
summary(d2, maxsum = 100)
n <- nrow(d2)
studies <- unique(d2$Study)
nstudies <- length(studies)



################### Meta-analysis for BETTER ###################

# Restructure data to fit meta-analysis package
d3 <- data.frame(cbind(unique(d2$Study),
                       tapply(d2$RelevantC == "Yes", d2$Study, sum, simplify = T),
                       table(d2$Study)))
colnames(d3) <- c("study", "cases", "total")
d3$proportion <- d3$cases / d3$total

# Calculate lower and upper limits of Clopper-pearson CI
d3$ll <- rep(NA, nrow(d3))
d3$ul <- rep(NA, nrow(d3))
for (istudy in 1:nrow(d3)) {
  d3$ll[istudy] <- CIp(d3$cases[istudy], d3$total[istudy])$conf.int[1]
  d3$ul[istudy] <- CIp(d3$cases[istudy], d3$total[istudy])$conf.int[2]
}

# Plot those CIs
plot(c(-.5, 1.5), c(1, nrow(d3)), type = "n")
for (istudy in 1:nrow(d3)) {
  points(d3$prop[istudy], istudy, pch = 22, bg = "gray")
  lines(c(d3$ll[istudy], d3$ul[istudy]), rep(istudy, 2))
}


# Perform actual meta-analysis using the meta-for package
library(metafor)

# Many studies with small samples and small proportions, so a double arcsine transformation is most fitting
d3[, 3:4]

# escalc calculate individual effect sizes and their corresponding sampling variances
ies.da <- escalc(xi = cases, ni = total, data = d3, measure = "PFT", add = 0)
# measure="PFT" #the double arcsine transformation
summary(ies.da)
# yi = estimate of cases, vi = variance
# sei = standard error

# rna pool individual effect sizes, and sampling variances, based on the inverse variance method
pes.da <- rma(yi, vi, data = ies.da, method = "REML")
# method="REML" #random effects using the restricted maximum-likelihood estimator

# pes contains the estimate of the summary proportion
pes.tf <- predict(pes.da, transf = transf.ipft.hm, targ = list(ni = d3$total))
summary(pes.da, digits = 2)
print(pes.tf, digits = 2)
# cr.lb = prediction interval

# Heterogeneity
confint(pes.da, digits = 2) # 95% CI

# Outliers
stud.res <- rstudent(pes.da)
abs.z <- abs(stud.res$z)
stud.res[order(-abs.z)] # </> +-2 can indicate outliers
# But no study actually influence the estimate to a relevant degree...
L1O <- leave1out(pes.da, transf = transf.ipft.hm, targ = list(ni = d3$total)); print(L1O)



### Lots of code to create summary figure
# random effect weights
d3$weights <- 1/(pes.da$vi + pes.da$tau2) / sum(1/(pes.da$vi + pes.da$tau2))

# Name and group studies for figure
study <- unique(d2$Study)
study <- study[c(c(19, 9, 10), # Summercamps
                 c(8, 2, 15, 18), # "Clinical"
                 c(4, 7, 13, 11, 12, 14, 17, 3, 16), # Thai setting
                 c(5, 1, 6))] # Uganda/Nepal
d3 <- d3[c(c(19, 9, 10), # Summercamps
           c(8, 2, 15, 18), # "Clinical"
           c(4, 7, 13, 11, 12, 14, 17, 3, 16), # Thai setting
           c(5, 1, 6)), ] # Uganda

# Intialize figure
setwd('C:/Users/andesa1/OneDrive - KI.SE/Dokument/LKG/Part2_systematicReview/Manuscript')
tiff(file="Fig_meta1.tiff", width = 200, height = 100, units = "mm", res = 1000, compression = "lzw")
par(mfcol = c(1, 1), bty = "l", mai = c(.6, .3, .3, .3))

# Create figure and axis
plot(c(-2, 2.5), c(-2, nrow(d3)+1), type = "n",
     xaxt = "n", bty = "n", yaxt = "n", xlab = "", ylab = "")
axis(1, at = seq(0, 1, by = .2),
     labels = F)
axis(1, at = seq(0, 1, by = .2),
     labels = seq(0, 1, by = .2),
     cex.axis = .7, line = -.5, lwd = -1)
title(xlab=expression("                      "~Proportion~improved),
      line = 1.5, cex.lab = .7)
lines(rep(pes.tf$pred, 2), c(0, nrow(d3)), lty = 2)

# Add each study
for (istudy in 1:nrow(d3)) {
  points(d3$prop[istudy], istudy, pch = 22, bg = "gray",
         cex = d3$weights[istudy]/max(d3$weights) * 1.5)
  lines(c(d3$ll[istudy], d3$ul[istudy]), rep(istudy, 2))
  
  text(-1.6, istudy, substring(study, 1)[istudy], cex = .7)
  text(-.8, istudy, d3$cases[istudy], cex = .7)
  text(-.5, istudy, d3$total[istudy], cex = .7)
  text(1.3, istudy, paste0(format(d3$proportion[istudy], digits = 2, nsmall = 2)), cex = .7)
  text(1.8, istudy, paste0("[", format(d3$ll[istudy], digits = 2, nsmall = 2), ", ",
                           format(d3$ul[istudy], digits=2, nsmall = 2), "]"), cex = .7)
  xweight <- d3$weights[istudy] * 100
  text(2.3, istudy, paste0(format(xweight, digits=1, nsmall = 1),"%"), cex = .7)
}

# Add meta-analysis result
polygon(c(pes.tf$ci.lb, pes.tf$pred, pes.tf$ci.ub, pes.tf$pred),
        c(-1, -.7, -1, -1.3), col = "white")
lines(c(pes.tf$ci.lb, pes.tf$ci.ub), rep(-1, 2), lwd = 2)
lines(c(pes.tf$cr.lb, pes.tf$cr.ub), rep(-2, 2), lwd = 2)
points(pes.tf$pred, -2, pch = 21, bg = "black")

# Add text
text(-1.6, nrow(d3)+1, "Study", font = 2, cex = .7)
text(-.8, nrow(d3)+1, "Improved", font = 2, cex = .7)
text(-.5, nrow(d3)+1, "N", font = 4, cex = .7)
text(-1.7, -1, "Random effects model", font = 2, cex = .7)
text(-.5, -1, sum(d3$total), font = 2, cex = .7)
text(1.3, nrow(d3)+1, "Proportion", font = 2, cex = .7)
text(1.3, -1, round(pes.tf$pred, 2), font = 2, cex = .7)
text(1.8, nrow(d3)+1, "95% CI", font = 2, cex = .7)
text(1.8, -1, paste0("[", round(pes.tf$ci.lb, 2), ", ",
                     round(pes.tf$ci.ub, 2), "]"), font = 2, cex = .7)
text(2.3, nrow(d3)+1, "Weight", font = 2, cex = .7)
text(2.3, -1, paste0(round(sum(d3$weights)*100),"%"), font = 2, cex = .7)
text(-1.4, -2, paste0("Heterogeneity, I = ", round(pes.da$I2),
                      "%, Q = ", round(pes.da$QE, 2)), cex = .7)
text(1.7, -2, paste0("Prediction interval [", format(pes.tf$cr.lb, digits = 2, nsmall = 2), ", ",
                     format(pes.tf$cr.ub, digits=2, nsmall = 2), "]"), cex = .7)

abline(h = c(3.5, 7.5, 16.5), lty = 2)

dev.off()



################### Logistic-regression for BETTER ###################

# Using months as predictor

# Recode relevant change to numeric
y <- rep(1, nrow(d2))
y[d2$RelevantC == "No"] <- 0

# Order participants based on age for figure
y <- y[order(d2$Months)]
study <- d2$Study[order(d2$Months)]
x <- sort(d2$Months)

### Apply simple (and wrong) logistic regression model
betterglmage.m1 <- glm(y ~ x, family = 'binomial')

### Apply mixed-effects model
library(lme4)
betterglmage.m2 <- glmer(y ~ x + (1|study), family = 'binomial') # Random intercept
betterglmage.m3 <- glmer(y ~ x + (x|study), family = 'binomial') # Random slopes

### Compare models
AIC(betterglmage.m1, betterglmage.m2, betterglmage.m3)

### Model 2 is the best
summary(betterglmage.m2)
round(coef(betterglmage.m2)$study, 3)
confs <- confint(betterglmage.m2)
round(confs, 3)
round(1.122, 2) # SD



### Codes to create figure

# X-axis and prediction to create regression line
new <- data.frame(x = round(seq(min(x), max(x), by = 1)))
pred_betterglmage.m2 <- 1 / (1 + exp(-(mean(coef(betterglmage.m2)$study[, 1]) + coef(betterglmage.m2)$study[1, 2]*new)))

# Intialize figure
setwd('C:/Users/andesa1/OneDrive - KI.SE/Dokument/LKG/Part2_systematicReview/Manuscript')
tiff(file="Fig_glmer1.tiff", width = 100, height = 100, units = "mm", res = 1000, compression = "lzw")
par(mfcol = c(1, 1), bty = "l", mai = c(.6, .6, .3, .3))

# Create figure and axis
plot(x,  betterglmage.m1$fitted.values, xaxt = "n", yaxt = "n",
     type = "n",
     ylim = c(0, 1),
     xlab = "", ylab = "", cex.lab = 1)
title(xlab=expression(Age~at~treatment~"("*years*")"),line = 1.5, cex.lab = 1)
title(ylab=expression(Probability~improved),line = 1.9, cex.lab = 1)
axis(1, at = seq(min(x), max(x), by = 12)-6,
     labels = F,
     tck = .03, cex.axis = .6)
axis(1, at = seq(min(x), max(x), by = 12)-6,
     labels = seq(min(x), max(x), by = 12)/12-.5,
     tck = .03, cex.axis = .8, line = -.9, lwd = -1)
axis(2, at = seq(0, 1, by = .2), labels = seq(0, 1, by = .2),
     cex.axis = .8, las = 1, line = 0)

# Add regression line
lines(new$x, pred_betterglmage.m2$x, lwd = 2)

# Add each study
for (istudy in 1:nstudies) {
  xx <- round(seq(min(x[study == studies[istudy]]), max(x[study == studies[istudy]]), by = 1))
  yy <- 1 / (1 + exp(-(coef(betterglmage.m2)$study[istudy, 1] + coef(betterglmage.m2)$study[1, 2]*xx)))
  lines(xx, yy, lty = 1, col = "gray")
}

dev.off()



################### Logistic-regression for BETTER ###################

# Using type of cleft as predictor

# Recode variables / recode type of cleft
y <- rep(1, nrow(d2))
y[d2$RelevantC == "No"] <- 0
x1 <- rep(0, nrow(d2))
x2 <- x1
x1[d2$Cleft == "BCLP"] <- 1
x2[d2$Cleft == "CP"] <- 1
x2[d2$Cleft == "SMCP"] <- 1
x2[d2$Cleft == "SPC"] <- 1
x1[d2$Cleft == "CL"] <- 3
study <- d2$Study

# Remove missing values
y <- y[!is.na(d2$Cleft)]
study <- study[!is.na(d2$Cleft)]
x2 <- x2[!is.na(d2$Cleft)]
x1 <- x1[!is.na(d2$Cleft)]

# Remove Cleft lip only
y <- y[-which(x1 == 3)]
study <- study[-which(x1 == 3)]
x2 <- x2[-which(x1 == 3)]
x1 <- x1[-which(x1 == 3)]

# Check correct coding
table(x1) # BCLP
table(x2) # CP (including SMCP, SPC)
table(x1, y)
table(x2, y)

### Apply simple (and wrong) logistic regression model
betterglmcleft.m1 <- glm(y ~ x1 + x2, family = 'binomial')
### Apply mixed-effects model
betterglmcleft.m2 <- glmer(y ~ x1 +x2 + (1|study), family = 'binomial')

### Compare models
AIC(betterglmcleft.m1, betterglmcleft.m2)

### Model 2 is the best
summary(betterglmcleft.m2)
round(1 / (1 + exp(- 1.3549)), 2) # prob for UCLP
round(1 / (1 + exp(- -0.6146 - 1.3549)), 2) # prob for BCLP
round(1 / (1 + exp(- -0.1852 - 1.3549)), 2) # prob for CP
round(1.3549 , 2) # intercept
round(-0.6146 , 2) # slope
round(-0.1852     , 2) # slope
round(coef(betterglmcleft.m2)$study, 3)
confs <- confint(betterglmcleft.m2)
round(confs, 2)
round(1.056    , 2) # std dev














################### Meta-analysis for GOOD ###################

# Restructure data to fit meta-analysis package
d4 <- data.frame(cbind(unique(d2$Study),
                       tapply(d2$EndPoint == "Good", d2$Study, sum, simplify = T),
                       table(d2$Study),
                       tapply(d2$Duration, d2$Study, mean)))
colnames(d4) <- c("study", "cases", "total", "duration")
d4$proportion <- d4$cases / d4$total

# Calculate lower and upper limits of Clopper-pearson CI
d4$ll <- rep(NA, nrow(d4))
d4$ul <- rep(NA, nrow(d4))
for (istudy in 1:nrow(d4)) {
  d4$ll[istudy] <- CIp(d4$cases[istudy], d4$total[istudy])$conf.int[1]
  d4$ul[istudy] <- CIp(d4$cases[istudy], d4$total[istudy])$conf.int[2]
}

# Plot those CIs
plot(c(-.5, 1.5), c(1, nrow(d4)), type = "n")
for (istudy in 1:nrow(d4)) {
  points(d4$prop[istudy], istudy, pch = 22, bg = "gray")
  lines(c(d4$ll[istudy], d4$ul[istudy]), rep(istudy, 2))
}


# Perform actual meta-analysis using the meta-for package
ies.da2 <- escalc(xi = cases, ni = total, data = d4, measure = "PFT", add = 0)
pes.da2 <- rma(yi, vi, data = ies.da2, method = "REML")
pes.tf2 <- predict(pes.da2, transf = transf.ipft.hm, targ = list(ni = d4$total))
summary(pes.da2, digits = 2)
print(pes.tf2, digits = 2)

# Heterogeneity
confint(pes.da2, digits = 2) # 95% CI [25, 89]

# Outliers
stud.res2 <- rstudent(pes.da2)
abs.z2 <- abs(stud.res2$z)
stud.res2[order(-abs.z2)] # </> +-2
# But no study actually influence the estimate to a relevant degree...
L1O2 <- leave1out(pes.da2, transf = transf.ipft.hm, targ = list(ni = d4$total)); print(L1O2)



### Lots of code to create summary figure
# random effect weights
d4$weights <- 1/(pes.da2$vi + pes.da2$tau2) / sum(1/(pes.da2$vi + pes.da2$tau2))

# Name and group studies for figure
study <- unique(d2$Study)
study <- study[c(c(19, 9, 10), # Summercamps
                 c(8, 2, 15, 18), # "Clinical"
                 c(4, 7, 13, 11, 12, 14, 17, 3, 16), # Thai setting
                 c(5, 1, 6))] # Uganda/Nepal
d4 <- d4[c(c(19, 9, 10), # Summercamps
           c(8, 2, 15, 18), # "Clinical"
           c(4, 7, 13, 11, 12, 14, 17, 3, 16), # Thai setting
           c(5, 1, 6)), ] # Uganda

# Intialize figure
tiff(file="Fig_meta2.tiff", width = 200, height = 100, units = "mm", res = 1000, compression = "lzw")
par(mfcol = c(1, 1), bty = "l", mai = c(.6, .3, .3, .3))

# Create figure and axis
plot(c(-2, 2.5), c(-2, nrow(d4)+1), type = "n",
     xaxt = "n", bty = "n", yaxt = "n", xlab = "", ylab = "")
axis(1, at = seq(0, 1, by = .2),
     labels = F)
axis(1, at = seq(0, 1, by = .2),
     labels = seq(0, 1, by = .2),
     cex.axis = .7, line = -.5, lwd = -1)
title(xlab=expression("                      "~Proportion~`peer-level`~speech),
      line = 1.5, cex.lab = .7)
lines(rep(pes.tf2$pred, 2), c(0, nrow(d4)), lty = 2)

# Add each study
for (istudy in 1:nrow(d4)) {
  points(d4$prop[istudy], istudy, pch = 22, bg = "gray",
         cex = d4$weights[istudy]/max(d4$weights) * 1.5)
  lines(c(d4$ll[istudy], d4$ul[istudy]), rep(istudy, 2))
  
  text(-1.6, istudy, substring(study, 1)[istudy], cex = .7)
  text(-.8, istudy, d4$cases[istudy], cex = .7)
  text(-.5, istudy, d4$total[istudy], cex = .7)
  text(1.3, istudy, paste0(format(d4$proportion[istudy], digits = 2, nsmall = 2)), cex = .7)
  text(1.8, istudy, paste0("[", format(d4$ll[istudy], digits = 2, nsmall = 2), ", ",
                           format(d4$ul[istudy], digits=2, nsmall = 2), "]"), cex = .7)
  xweight <- d4$weights[istudy] * 100
  text(2.3, istudy, paste0(format(xweight, digits=1, nsmall = 1),"%"), cex = .7)
}

# Add meta-analysis result
polygon(c(pes.tf2$ci.lb, pes.tf2$pred, pes.tf2$ci.ub, pes.tf2$pred),
        c(-1, -.7, -1, -1.3), col = "white")
lines(c(pes.tf2$ci.lb, pes.tf2$ci.ub), rep(-1, 2), lwd = 2)
lines(c(pes.tf2$cr.lb, pes.tf2$cr.ub), rep(-2, 2), lwd = 2)
points(pes.tf2$pred, -2, pch = 21, bg = "black")

# Add text
text(-1.6, nrow(d4)+1, "Study", font = 2, cex = .7)
text(-.8, nrow(d4)+1, "Peer-level", font = 2, cex = .7)
text(-.5, nrow(d4)+1, "N", font = 4, cex = .7)
text(-1.7, -1, "Random effects model", font = 2, cex = .7)
text(-.5, -1, sum(d4$total), font = 2, cex = .7)
text(1.3, nrow(d4)+1, "Proportion", font = 2, cex = .7)
text(1.3, -1, round(pes.tf2$pred, 2), font = 2, cex = .7)
text(1.8, nrow(d4)+1, "95% CI", font = 2, cex = .7)
text(1.8, -1, paste0("[", format(pes.tf2$ci.lb, digits = 2, nsmall = 2), ", ",
                     format(pes.tf2$ci.ub, digits = 2, nsmall = 2), "]"), font = 2, cex = .7)
text(2.3, nrow(d4)+1, "Weight", font = 2, cex = .7)
text(2.3, -1, paste0(round(sum(d4$weights)*100),"%"), font = 2, cex = .7)
text(-1.4, -2, paste0("Heterogeneity, I = ", round(pes.da2$I2),
                      "%, Q = ", format(pes.da2$QE, digits = 2, nsmall = 2)), cex = .7)
text(1.7, -2, paste0("Prediction interval [", format(pes.tf2$cr.lb, digits = 2, nsmall = 2), ", ",
                     format(pes.tf2$cr.ub, digits=2, nsmall = 2), "]"), cex = .7)

abline(h = c(3.5, 7.5, 16.5), lty = 2)

dev.off()




################### Meta-regression for GOOD ###################

# Metaregression using intervention duration as predictor
metareg.moderator <- rma(yi, vi, data = ies.da2, mods = ~ duration, method = "REML")
summary(metareg.moderator)
round(coef(metareg.moderator), 2)
confint(metareg.moderator)

maxpred <- max(d2$Duration, na.rm = T) # Just max value on the x-axis for figure
# Below to get predicted values and CIs
metareg.preds <- predict(metareg.moderator, transf = transf.ipft.hm, targ = list(ni = d3$total),
                         newmods = seq(1, maxpred, 1))

# Add jitter on x-axis to figure
jitter <- rep(0, 19)
jitter[c(11, 14, 19)] <- c(-.3, .3, .3)
cbind(d4$duration, d4$duration + jitter, d4$proportion)

# Intialize figure
tiff(file="Fig_metareg1.tiff", width = 100, height = 100, units = "mm", res = 1000, compression = "lzw")
par(mfcol = c(1, 1), bty = "l", mai = c(.6, .6, .3, .3))

# Create figure and axis
plot(c(0, maxpred), c(0, 1), xaxt = "n", yaxt = "n",
     type = "n",
     ylim = c(0, 1), xlim = c(0, maxpred),
     xlab = "", ylab = "", cex.lab = 1)
title(xlab=expression(Intervention~duration~"("*weeks*")"),line = 1.5, cex.lab = 1)
title(ylab=expression(Proportion~`peer-level`~speech),line = 1.9, cex.lab = 1)
axis(1, at = seq(0, maxpred, by = 5),
     labels = F,
     tck = .03, cex.axis = .6)
axis(1, at = seq(0, maxpred, by = 5),
     labels = seq(0, maxpred, by = 5),
     tck = .03, cex.axis = .8, line = -.9, lwd = -1)
axis(2, at = seq(0, 1, by = .2), labels = seq(0, 1, by = .2),
     cex.axis = .8, las = 1, line = 0)

# Add regression lines
lines(seq(1, maxpred, 1), metareg.preds$pred, lwd = 2)
lines(seq(1, maxpred, 1), metareg.preds$ci.lb, lty = 2, col = "gray")
lines(seq(1, maxpred, 1), metareg.preds$ci.ub, lty = 2, col = "gray")

# Add each study
points(d4$duration + jitter, d4$proportion,
       cex = d4$weights/max(d4$weights) * 1.5)

dev.off()


################### Logistic-regression for GOOD ###################

# Using months as predictor

# Recode relevant change to numeric
y <- rep(0, nrow(d2))
y[d2$EndPoint == "Good"] <- 1
# Order participants based on age for figure
y <- y[order(d2$Months)]
study <- d2$Study[order(d2$Months)]
x <- sort(d2$Months)

### Apply simple (and wrong) logistic regression model
goodglmage.m1 <- glm(y ~ x, family = 'binomial')

### Apply mixed-effects model
goodglmage.m2 <- glmer(y ~ x + (1|study), family = 'binomial') # Random intercept
goodglmage.m3 <- glmer(y ~ x + (x|study), family = 'binomial') # Random slopes

### Compare models
AIC(goodglmage.m1, goodglmage.m2, goodglmage.m3)

### Model 2 is the best
summary(goodglmage.m2)
round(coef(goodglmage.m2)$study, 3)
confs <- confint(goodglmage.m2)
round(confs, 3)
round(1.236, 2) # std dev



### Codes to create figure

# X-axis and prediction to create regression line
new <- data.frame(x = round(seq(min(x), max(x), by = 1)))
pred_goodglmage.m2 <- 1 / (1 + exp(-(mean(coef(goodglmage.m2)$study[, 1]) + coef(goodglmage.m2)$study[1, 2]*new)))

# Intialize figure
tiff(file="Fig_glmer2.tiff", width = 100, height = 100, units = "mm", res = 1000, compression = "lzw")
par(mfcol = c(1, 1), bty = "l", mai = c(.6, .6, .3, .3))

# Create figure and axis
plot(x,  goodglmage.m1$fitted.values, xaxt = "n", yaxt = "n",
     type = "n",
     ylim = c(0, 1),
     xlab = "", ylab = "", cex.lab = 1)
title(xlab=expression(Age~at~treatment~"("*years*")"),line = 1.5, cex.lab = 1)
title(ylab=expression(Probability~`peer-level`~speech),line = 1.9, cex.lab = 1)
axis(1, at = seq(min(x), max(x), by = 12)-6,
     labels = F,
     tck = .03, cex.axis = .6)
axis(1, at = seq(min(x), max(x), by = 12)-6,
     labels = seq(min(x), max(x), by = 12)/12-.5,
     tck = .03, cex.axis = .8, line = -.9, lwd = -1)
axis(2, at = seq(0, 1, by = .2), labels = seq(0, 1, by = .2),
     cex.axis = .8, las = 1, line = 0)

# Add regression line
lines(new$x, pred_goodglmage.m2$x, lwd = 2)

# Add each study
for (istudy in 1:nstudies) {
  xx <- round(seq(min(x[study == studies[istudy]]), max(x[study == studies[istudy]]), by = 1))
  yy <- 1 / (1 + exp(-(coef(goodglmage.m2)$study[istudy, 1] + coef(goodglmage.m2)$study[1, 2]*xx)))
  lines(xx, yy, lty = 1, col = "gray")
}

dev.off()



################### Logistic-regression for BETTER ###################

# Using type of cleft as predictor

# Recode variables / recode type of cleft
y <- rep(0, nrow(d2))
y[d2$EndPoint == "Good"] <- 1
x1 <- rep(0, nrow(d2))
x2 <- x1
x1[d2$Cleft == "BCLP"] <- 1
x2[d2$Cleft == "CP"] <- 1
x2[d2$Cleft == "SMCP"] <- 1
x2[d2$Cleft == "SPC"] <- 1
x1[d2$Cleft == "CL"] <- 3
study <- d2$Study

# Remove missing values
y <- y[!is.na(d2$Cleft)]
study <- study[!is.na(d2$Cleft)]
x2 <- x2[!is.na(d2$Cleft)]
x1 <- x1[!is.na(d2$Cleft)]

# Remove Cleft lip only
y <- y[-which(x1 == 3)]
study <- study[-which(x1 == 3)]
x2 <- x2[-which(x1 == 3)]
x1 <- x1[-which(x1 == 3)]

# Check correct coding
table(x1) # BCLP
table(x2) # CP (including SMCP, SPC)
table(x1, y)
table(x2, y)

### Apply simple (and wrong) logistic regression model
goodglmcleft.m1 <- glm(y ~ x1 + x2, family = 'binomial')
### Apply mixed-effects model
goodglmcleft.m2 <- glmer(y ~ x1 +x2 + (1|study), family = 'binomial')

### Compare models
AIC(goodglmcleft.m1, goodglmcleft.m2)

### Model 2 is the best
summary(goodglmcleft.m2)
round(1 / (1 + exp(- -1.59494    )), 2) # prob for UCLP
round(1 / (1 + exp(- -0.06074     - -1.59494        )), 2) # prob for BCLP
round(1 / (1 + exp(- 1.01176     - -1.59494        )), 2) # prob for CP
round(-1.59494        , 2) # intercept
round(-0.06074        , 2) # slope
round(1.01176        , 2) # slope
round(coef(goodglmcleft.m2)$study, 3)
confs <- confint(goodglmcleft.m2)
round(confs, 2)
round(1.327         , 2) # std dev

